@@ -47,35 +47,35 @@ class RenogyChargeController(minimalmodbus.Instrument):
 
     def get_solar_voltage(self):
         """PV array input in volts"""
-        return self.retriable_read_float(0x0107, 2) * 10
+        return self.retriable_read_float(0x0107, 3, 2) * 10
 
     def get_solar_current(self):
         """PV array input in amps"""
-        return self.retriable_read_float(0x0108, 2) * 100
+        return self.retriable_read_float(0x0108, 3, 2) * 100
 
     def get_solar_power(self):
         """PV array input in watts"""
-        return self.retriable_read_float(0x0109, 2)
+        return self.retriable_read_float(0x0109, 3, 2)
 
     def get_load_voltage(self):
         """Load output in volts"""
-        return self.retriable_read_float(0x0104, 2)  * 10
+        return self.retriable_read_float(0x0104, 3, 2)  * 10
 
     def get_load_current(self):
         """Load output in amps"""
-        return self.retriable_read_float(0x0105, 2) * 100
+        return self.retriable_read_float(0x0105, 3, 2) * 100
 
     def get_load_power(self):
         """Load output in watts"""
-        return self.retriable_read_float(0x0106, 2)
+        return self.retriable_read_float(0x0106, 3, 2)
 
     def get_battery_voltage(self):
         """Battery voltage"""
-        return self.retriable_read_float(0x0101, 2) * 10
+        return self.retriable_read_float(0x0101, 3, 2) * 10
 
     def get_battery_state_of_charge(self):
         """Battery state of charge"""
-        return self.retriable_read_float(0x0100, 2)
+        return self.retriable_read_float(0x0100, 3, 2)
 
     def get_battery_temperature(self):
         """battery temperature"""
